# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_cloud.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13gcp/gcp_cloud.proto\x12\x15oak9.tython.gcp.cloud\x1a\x13shared/shared.proto\"j\n\x1e\x43loudAssetFolderFeedXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\"H\n7CloudAssetFolderFeedXFeedOutputConfigXPubsubDestination\x12\r\n\x05topic\x18\x01 \x01(\t\"\x93\x01\n%CloudAssetFolderFeedXFeedOutputConfig\x12j\n\x12pubsub_destination\x18\x01 \x01(\x0b\x32N.oak9.tython.gcp.cloud.CloudAssetFolderFeedXFeedOutputConfigXPubsubDestination\"O\n\x1d\x43loudAssetFolderFeedXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xe2\x03\n\x14\x43loudAssetFolderFeed\x12\x13\n\x0b\x61sset_names\x18\x01 \x03(\t\x12\x13\n\x0b\x61sset_types\x18\x02 \x03(\t\x12\x17\n\x0f\x62illing_project\x18\x03 \x01(\t\x12\x14\n\x0c\x63ontent_type\x18\x04 \x01(\t\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x05 \x01(\t\x12\x0e\n\x06\x66older\x18\x06 \x01(\t\x12\x11\n\tfolder_id\x18\x07 \x01(\t\x12\n\n\x02id\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\x12H\n\tcondition\x18\n \x01(\x0b\x32\x35.oak9.tython.gcp.cloud.CloudAssetFolderFeedXCondition\x12X\n\x12\x66\x65\x65\x64_output_config\x18\x0b \x01(\x0b\x32<.oak9.tython.gcp.cloud.CloudAssetFolderFeedXFeedOutputConfig\x12\x46\n\x08timeouts\x18\x0c \x01(\x0b\x32\x34.oak9.tython.gcp.cloud.CloudAssetFolderFeedXTimeouts\x12\x37\n\rresource_info\x18\r \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"p\n$CloudAssetOrganizationFeedXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\"N\n=CloudAssetOrganizationFeedXFeedOutputConfigXPubsubDestination\x12\r\n\x05topic\x18\x01 \x01(\t\"\x9f\x01\n+CloudAssetOrganizationFeedXFeedOutputConfig\x12p\n\x12pubsub_destination\x18\x01 \x01(\x0b\x32T.oak9.tython.gcp.cloud.CloudAssetOrganizationFeedXFeedOutputConfigXPubsubDestination\"U\n#CloudAssetOrganizationFeedXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xe7\x03\n\x1a\x43loudAssetOrganizationFeed\x12\x13\n\x0b\x61sset_names\x18\x01 \x03(\t\x12\x13\n\x0b\x61sset_types\x18\x02 \x03(\t\x12\x17\n\x0f\x62illing_project\x18\x03 \x01(\t\x12\x14\n\x0c\x63ontent_type\x18\x04 \x01(\t\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0e\n\x06org_id\x18\x08 \x01(\t\x12N\n\tcondition\x18\t \x01(\x0b\x32;.oak9.tython.gcp.cloud.CloudAssetOrganizationFeedXCondition\x12^\n\x12\x66\x65\x65\x64_output_config\x18\n \x01(\x0b\x32\x42.oak9.tython.gcp.cloud.CloudAssetOrganizationFeedXFeedOutputConfig\x12L\n\x08timeouts\x18\x0b \x01(\x0b\x32:.oak9.tython.gcp.cloud.CloudAssetOrganizationFeedXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"k\n\x1f\x43loudAssetProjectFeedXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\"I\n8CloudAssetProjectFeedXFeedOutputConfigXPubsubDestination\x12\r\n\x05topic\x18\x01 \x01(\t\"\x95\x01\n&CloudAssetProjectFeedXFeedOutputConfig\x12k\n\x12pubsub_destination\x18\x01 \x01(\x0b\x32O.oak9.tython.gcp.cloud.CloudAssetProjectFeedXFeedOutputConfigXPubsubDestination\"P\n\x1e\x43loudAssetProjectFeedXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xd4\x03\n\x15\x43loudAssetProjectFeed\x12\x13\n\x0b\x61sset_names\x18\x01 \x03(\t\x12\x13\n\x0b\x61sset_types\x18\x02 \x03(\t\x12\x17\n\x0f\x62illing_project\x18\x03 \x01(\t\x12\x14\n\x0c\x63ontent_type\x18\x04 \x01(\t\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12I\n\tcondition\x18\t \x01(\x0b\x32\x36.oak9.tython.gcp.cloud.CloudAssetProjectFeedXCondition\x12Y\n\x12\x66\x65\x65\x64_output_config\x18\n \x01(\x0b\x32=.oak9.tython.gcp.cloud.CloudAssetProjectFeedXFeedOutputConfig\x12G\n\x08timeouts\x18\x0b \x01(\x0b\x32\x35.oak9.tython.gcp.cloud.CloudAssetProjectFeedXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"<\n\x1b\x43loudIdentityGroupXGroupKey\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\"M\n\x1b\x43loudIdentityGroupXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xed\x03\n\x12\x43loudIdentityGroup\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x1c\n\x14initial_group_config\x18\x05 \x01(\t\x12\x45\n\x06labels\x18\x06 \x03(\x0b\x32\x35.oak9.tython.gcp.cloud.CloudIdentityGroup.LabelsEntry\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0e\n\x06parent\x18\x08 \x01(\t\x12\x13\n\x0bupdate_time\x18\t \x01(\t\x12\x45\n\tgroup_key\x18\n \x01(\x0b\x32\x32.oak9.tython.gcp.cloud.CloudIdentityGroupXGroupKey\x12\x44\n\x08timeouts\x18\x0b \x01(\x0b\x32\x32.oak9.tython.gcp.cloud.CloudIdentityGroupXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"P\n/CloudIdentityGroupMembershipXPreferredMemberKey\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\"2\n\"CloudIdentityGroupMembershipXRoles\x12\x0c\n\x04name\x18\x01 \x01(\t\"W\n%CloudIdentityGroupMembershipXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb8\x03\n\x1c\x43loudIdentityGroupMembership\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\r\n\x05group\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x13\n\x0bupdate_time\x18\x06 \x01(\t\x12\x64\n\x14preferred_member_key\x18\x07 \x01(\x0b\x32\x46.oak9.tython.gcp.cloud.CloudIdentityGroupMembershipXPreferredMemberKey\x12H\n\x05roles\x18\x08 \x03(\x0b\x32\x39.oak9.tython.gcp.cloud.CloudIdentityGroupMembershipXRoles\x12N\n\x08timeouts\x18\t \x01(\x0b\x32<.oak9.tython.gcp.cloud.CloudIdentityGroupMembershipXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x94\x03\n\x1e\x43loudRunDomainMappingXMetadata\x12[\n\x0b\x61nnotations\x18\x01 \x03(\x0b\x32\x46.oak9.tython.gcp.cloud.CloudRunDomainMappingXMetadata.AnnotationsEntry\x12\x12\n\ngeneration\x18\x02 \x01(\x01\x12Q\n\x06labels\x18\x03 \x03(\x0b\x32\x41.oak9.tython.gcp.cloud.CloudRunDomainMappingXMetadata.LabelsEntry\x12\x11\n\tnamespace\x18\x04 \x01(\t\x12\x18\n\x10resource_version\x18\x05 \x01(\t\x12\x11\n\tself_link\x18\x06 \x01(\t\x12\x0b\n\x03uid\x18\x07 \x01(\t\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"b\n\x1a\x43loudRunDomainMappingXSpec\x12\x18\n\x10\x63\x65rtificate_mode\x18\x01 \x01(\t\x12\x16\n\x0e\x66orce_override\x18\x02 \x01(\x08\x12\x12\n\nroute_name\x18\x03 \x01(\t\"@\n\x1e\x43loudRunDomainMappingXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xd9\x03\n\x15\x43loudRunDomainMapping\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12H\n\x06status\x18\x05 \x03(\x0b\x32\x38.oak9.tython.gcp.cloud.CloudRunDomainMapping.StatusEntry\x12G\n\x08metadata\x18\x06 \x01(\x0b\x32\x35.oak9.tython.gcp.cloud.CloudRunDomainMappingXMetadata\x12?\n\x04spec\x18\x07 \x01(\x0b\x32\x31.oak9.tython.gcp.cloud.CloudRunDomainMappingXSpec\x12G\n\x08timeouts\x18\x08 \x01(\x0b\x32\x35.oak9.tython.gcp.cloud.CloudRunDomainMappingXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bStatusEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x82\x03\n\x18\x43loudRunServiceXMetadata\x12U\n\x0b\x61nnotations\x18\x01 \x03(\x0b\x32@.oak9.tython.gcp.cloud.CloudRunServiceXMetadata.AnnotationsEntry\x12\x12\n\ngeneration\x18\x02 \x01(\x01\x12K\n\x06labels\x18\x03 \x03(\x0b\x32;.oak9.tython.gcp.cloud.CloudRunServiceXMetadata.LabelsEntry\x12\x11\n\tnamespace\x18\x04 \x01(\t\x12\x18\n\x10resource_version\x18\x05 \x01(\t\x12\x11\n\tself_link\x18\x06 \x01(\t\x12\x0b\n\x03uid\x18\x07 \x01(\t\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xab\x03\n!CloudRunServiceXTemplateXMetadata\x12^\n\x0b\x61nnotations\x18\x01 \x03(\x0b\x32I.oak9.tython.gcp.cloud.CloudRunServiceXTemplateXMetadata.AnnotationsEntry\x12\x12\n\ngeneration\x18\x02 \x01(\x01\x12T\n\x06labels\x18\x03 \x03(\x0b\x32\x44.oak9.tython.gcp.cloud.CloudRunServiceXTemplateXMetadata.LabelsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x11\n\tnamespace\x18\x05 \x01(\t\x12\x18\n\x10resource_version\x18\x06 \x01(\t\x12\x11\n\tself_link\x18\x07 \x01(\t\x12\x0b\n\x03uid\x18\x08 \x01(\t\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"`\nCCloudRunServiceXTemplateXSpecXContainersXEnvXValueFromXSecretKeyRef\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xac\x01\n6CloudRunServiceXTemplateXSpecXContainersXEnvXValueFrom\x12r\n\x0esecret_key_ref\x18\x01 \x01(\x0b\x32Z.oak9.tython.gcp.cloud.CloudRunServiceXTemplateXSpecXContainersXEnvXValueFromXSecretKeyRef\"\xae\x01\n,CloudRunServiceXTemplateXSpecXContainersXEnv\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x61\n\nvalue_from\x18\x03 \x01(\x0b\x32M.oak9.tython.gcp.cloud.CloudRunServiceXTemplateXSpecXContainersXEnvXValueFrom\"b\nRCloudRunServiceXTemplateXSpecXContainersXEnvFromXConfigMapRefXLocalObjectReference\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xdd\x01\n=CloudRunServiceXTemplateXSpecXContainersXEnvFromXConfigMapRef\x12\x10\n\x08optional\x18\x01 \x01(\x08\x12\x89\x01\n\x16local_object_reference\x18\x02 \x01(\x0b\x32i.oak9.tython.gcp.cloud.CloudRunServiceXTemplateXSpecXContainersXEnvFromXConfigMapRefXLocalObjectReference\"_\nOCloudRunServiceXTemplateXSpecXContainersXEnvFromXSecretRefXLocalObjectReference\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xd7\x01\n:CloudRunServiceXTemplateXSpecXContainersXEnvFromXSecretRef\x12\x10\n\x08optional\x18\x01 \x01(\x08\x12\x86\x01\n\x16local_object_reference\x18\x02 \x01(\x0b\x32\x66.oak9.tython.gcp.cloud.CloudRunServiceXTemplateXSpecXContainersXEnvFromXSecretRefXLocalObjectReference\"\x97\x02\n0CloudRunServiceXTemplateXSpecXContainersXEnvFrom\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12l\n\x0e\x63onfig_map_ref\x18\x02 \x01(\x0b\x32T.oak9.tython.gcp.cloud.CloudRunServiceXTemplateXSpecXContainersXEnvFromXConfigMapRef\x12\x65\n\nsecret_ref\x18\x03 \x01(\x0b\x32Q.oak9.tython.gcp.cloud.CloudRunServiceXTemplateXSpecXContainersXEnvFromXSecretRef\"h\n.CloudRunServiceXTemplateXSpecXContainersXPorts\x12\x16\n\x0e\x63ontainer_port\x18\x01 \x01(\x01\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08protocol\x18\x03 \x01(\t\"\xe6\x02\n2CloudRunServiceXTemplateXSpecXContainersXResources\x12\x65\n\x06limits\x18\x01 \x03(\x0b\x32U.oak9.tython.gcp.cloud.CloudRunServiceXTemplateXSpecXContainersXResources.LimitsEntry\x12i\n\x08requests\x18\x02 \x03(\x0b\x32W.oak9.tython.gcp.cloud.CloudRunServiceXTemplateXSpecXContainersXResources.RequestsEntry\x1a-\n\x0bLimitsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rRequestsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Y\n5CloudRunServiceXTemplateXSpecXContainersXVolumeMounts\x12\x12\n\nmount_path\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xb3\x04\n(CloudRunServiceXTemplateXSpecXContainers\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\x12\x0f\n\x07\x63ommand\x18\x02 \x03(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x13\n\x0bworking_dir\x18\x04 \x01(\t\x12P\n\x03\x65nv\x18\x05 \x03(\x0b\x32\x43.oak9.tython.gcp.cloud.CloudRunServiceXTemplateXSpecXContainersXEnv\x12Y\n\x08\x65nv_from\x18\x06 \x03(\x0b\x32G.oak9.tython.gcp.cloud.CloudRunServiceXTemplateXSpecXContainersXEnvFrom\x12T\n\x05ports\x18\x07 \x03(\x0b\x32\x45.oak9.tython.gcp.cloud.CloudRunServiceXTemplateXSpecXContainersXPorts\x12\\\n\tresources\x18\x08 \x01(\x0b\x32I.oak9.tython.gcp.cloud.CloudRunServiceXTemplateXSpecXContainersXResources\x12\x63\n\rvolume_mounts\x18\t \x03(\x0b\x32L.oak9.tython.gcp.cloud.CloudRunServiceXTemplateXSpecXContainersXVolumeMounts\"]\n2CloudRunServiceXTemplateXSpecXVolumesXSecretXItems\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04mode\x18\x02 \x01(\x01\x12\x0c\n\x04path\x18\x03 \x01(\t\"\xb3\x01\n,CloudRunServiceXTemplateXSpecXVolumesXSecret\x12\x14\n\x0c\x64\x65\x66\x61ult_mode\x18\x01 \x01(\x01\x12\x13\n\x0bsecret_name\x18\x02 \x01(\t\x12X\n\x05items\x18\x03 \x03(\x0b\x32I.oak9.tython.gcp.cloud.CloudRunServiceXTemplateXSpecXVolumesXSecretXItems\"\x8a\x01\n%CloudRunServiceXTemplateXSpecXVolumes\x12\x0c\n\x04name\x18\x01 \x01(\t\x12S\n\x06secret\x18\x02 \x01(\x0b\x32\x43.oak9.tython.gcp.cloud.CloudRunServiceXTemplateXSpecXVolumesXSecret\"\xb0\x02\n\x1d\x43loudRunServiceXTemplateXSpec\x12\x1d\n\x15\x63ontainer_concurrency\x18\x01 \x01(\x01\x12\x1c\n\x14service_account_name\x18\x02 \x01(\t\x12\x15\n\rserving_state\x18\x03 \x01(\t\x12\x17\n\x0ftimeout_seconds\x18\x04 \x01(\x01\x12S\n\ncontainers\x18\x05 \x03(\x0b\x32?.oak9.tython.gcp.cloud.CloudRunServiceXTemplateXSpecXContainers\x12M\n\x07volumes\x18\x06 \x03(\x0b\x32<.oak9.tython.gcp.cloud.CloudRunServiceXTemplateXSpecXVolumes\"\xaa\x01\n\x18\x43loudRunServiceXTemplate\x12J\n\x08metadata\x18\x01 \x01(\x0b\x32\x38.oak9.tython.gcp.cloud.CloudRunServiceXTemplateXMetadata\x12\x42\n\x04spec\x18\x02 \x01(\x0b\x32\x34.oak9.tython.gcp.cloud.CloudRunServiceXTemplateXSpec\"J\n\x18\x43loudRunServiceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"t\n\x17\x43loudRunServiceXTraffic\x12\x17\n\x0flatest_revision\x18\x01 \x01(\x08\x12\x0f\n\x07percent\x18\x02 \x01(\x01\x12\x15\n\rrevision_name\x18\x03 \x01(\t\x12\x0b\n\x03tag\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\"\xa8\x04\n\x0f\x43loudRunService\x12\"\n\x1a\x61utogenerate_revision_name\x18\x01 \x01(\x08\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x42\n\x06status\x18\x06 \x03(\x0b\x32\x32.oak9.tython.gcp.cloud.CloudRunService.StatusEntry\x12\x41\n\x08metadata\x18\x07 \x01(\x0b\x32/.oak9.tython.gcp.cloud.CloudRunServiceXMetadata\x12\x41\n\x08template\x18\x08 \x01(\x0b\x32/.oak9.tython.gcp.cloud.CloudRunServiceXTemplate\x12\x41\n\x08timeouts\x18\t \x01(\x0b\x32/.oak9.tython.gcp.cloud.CloudRunServiceXTimeouts\x12?\n\x07traffic\x18\n \x03(\x0b\x32..oak9.tython.gcp.cloud.CloudRunServiceXTraffic\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bStatusEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n#CloudRunServiceIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x90\x02\n\x19\x43loudRunServiceIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x0f\n\x07service\x18\x07 \x01(\t\x12M\n\tcondition\x18\x08 \x01(\x0b\x32:.oak9.tython.gcp.cloud.CloudRunServiceIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\\\n\"CloudRunServiceIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x8d\x02\n\x18\x43loudRunServiceIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x0f\n\x07service\x18\x07 \x01(\t\x12L\n\tcondition\x18\x08 \x01(\x0b\x32\x39.oak9.tython.gcp.cloud.CloudRunServiceIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb6\x01\n\x18\x43loudRunServiceIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0f\n\x07service\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"l\n6CloudSchedulerJobXAppEngineHttpTargetXAppEngineRouting\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0f\n\x07service\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\"\xd7\x02\n%CloudSchedulerJobXAppEngineHttpTarget\x12\x0c\n\x04\x62ody\x18\x01 \x01(\t\x12Z\n\x07headers\x18\x02 \x03(\x0b\x32I.oak9.tython.gcp.cloud.CloudSchedulerJobXAppEngineHttpTarget.HeadersEntry\x12\x13\n\x0bhttp_method\x18\x03 \x01(\t\x12\x14\n\x0crelative_uri\x18\x04 \x01(\t\x12i\n\x12\x61pp_engine_routing\x18\x05 \x01(\x0b\x32M.oak9.tython.gcp.cloud.CloudSchedulerJobXAppEngineHttpTargetXAppEngineRouting\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"W\n\'CloudSchedulerJobXHttpTargetXOauthToken\x12\r\n\x05scope\x18\x01 \x01(\t\x12\x1d\n\x15service_account_email\x18\x02 \x01(\t\"Y\n&CloudSchedulerJobXHttpTargetXOidcToken\x12\x10\n\x08\x61udience\x18\x01 \x01(\t\x12\x1d\n\x15service_account_email\x18\x02 \x01(\t\"\xf9\x02\n\x1c\x43loudSchedulerJobXHttpTarget\x12\x0c\n\x04\x62ody\x18\x01 \x01(\t\x12Q\n\x07headers\x18\x02 \x03(\x0b\x32@.oak9.tython.gcp.cloud.CloudSchedulerJobXHttpTarget.HeadersEntry\x12\x13\n\x0bhttp_method\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\x12S\n\x0boauth_token\x18\x05 \x01(\x0b\x32>.oak9.tython.gcp.cloud.CloudSchedulerJobXHttpTargetXOauthToken\x12Q\n\noidc_token\x18\x06 \x01(\x0b\x32=.oak9.tython.gcp.cloud.CloudSchedulerJobXHttpTargetXOidcToken\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd0\x01\n\x1e\x43loudSchedulerJobXPubsubTarget\x12Y\n\nattributes\x18\x01 \x03(\x0b\x32\x45.oak9.tython.gcp.cloud.CloudSchedulerJobXPubsubTarget.AttributesEntry\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\x12\x12\n\ntopic_name\x18\x03 \x01(\t\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa3\x01\n\x1d\x43loudSchedulerJobXRetryConfig\x12\x1c\n\x14max_backoff_duration\x18\x01 \x01(\t\x12\x15\n\rmax_doublings\x18\x02 \x01(\x01\x12\x1a\n\x12max_retry_duration\x18\x03 \x01(\t\x12\x1c\n\x14min_backoff_duration\x18\x04 \x01(\t\x12\x13\n\x0bretry_count\x18\x05 \x01(\x01\"L\n\x1a\x43loudSchedulerJobXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xe2\x04\n\x11\x43loudSchedulerJob\x12\x18\n\x10\x61ttempt_deadline\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x10\n\x08schedule\x18\x07 \x01(\t\x12\x11\n\ttime_zone\x18\x08 \x01(\t\x12\\\n\x16\x61pp_engine_http_target\x18\t \x01(\x0b\x32<.oak9.tython.gcp.cloud.CloudSchedulerJobXAppEngineHttpTarget\x12H\n\x0bhttp_target\x18\n \x01(\x0b\x32\x33.oak9.tython.gcp.cloud.CloudSchedulerJobXHttpTarget\x12L\n\rpubsub_target\x18\x0b \x01(\x0b\x32\x35.oak9.tython.gcp.cloud.CloudSchedulerJobXPubsubTarget\x12J\n\x0cretry_config\x18\x0c \x01(\x0b\x32\x34.oak9.tython.gcp.cloud.CloudSchedulerJobXRetryConfig\x12\x43\n\x08timeouts\x18\r \x01(\x0b\x32\x31.oak9.tython.gcp.cloud.CloudSchedulerJobXTimeouts\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"l\n(CloudTasksQueueXAppEngineRoutingOverride\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x10\n\x08instance\x18\x02 \x01(\t\x12\x0f\n\x07service\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\"z\n\x1a\x43loudTasksQueueXRateLimits\x12\x16\n\x0emax_burst_size\x18\x01 \x01(\x01\x12!\n\x19max_concurrent_dispatches\x18\x02 \x01(\x01\x12!\n\x19max_dispatches_per_second\x18\x03 \x01(\x01\"\x90\x01\n\x1b\x43loudTasksQueueXRetryConfig\x12\x14\n\x0cmax_attempts\x18\x01 \x01(\x01\x12\x13\n\x0bmax_backoff\x18\x02 \x01(\t\x12\x15\n\rmax_doublings\x18\x03 \x01(\x01\x12\x1a\n\x12max_retry_duration\x18\x04 \x01(\t\x12\x13\n\x0bmin_backoff\x18\x05 \x01(\t\"B\n(CloudTasksQueueXStackdriverLoggingConfig\x12\x16\n\x0esampling_ratio\x18\x01 \x01(\x01\"J\n\x18\x43loudTasksQueueXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa7\x04\n\x0f\x43loudTasksQueue\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x64\n\x1b\x61pp_engine_routing_override\x18\x05 \x01(\x0b\x32?.oak9.tython.gcp.cloud.CloudTasksQueueXAppEngineRoutingOverride\x12\x46\n\x0brate_limits\x18\x06 \x01(\x0b\x32\x31.oak9.tython.gcp.cloud.CloudTasksQueueXRateLimits\x12H\n\x0cretry_config\x18\x07 \x01(\x0b\x32\x32.oak9.tython.gcp.cloud.CloudTasksQueueXRetryConfig\x12\x63\n\x1astackdriver_logging_config\x18\x08 \x01(\x0b\x32?.oak9.tython.gcp.cloud.CloudTasksQueueXStackdriverLoggingConfig\x12\x41\n\x08timeouts\x18\t \x01(\x0b\x32/.oak9.tython.gcp.cloud.CloudTasksQueueXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"]\n#CloudTasksQueueIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x8d\x02\n\x19\x43loudTasksQueueIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12M\n\tcondition\x18\x08 \x01(\x0b\x32:.oak9.tython.gcp.cloud.CloudTasksQueueIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\\\n\"CloudTasksQueueIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x8a\x02\n\x18\x43loudTasksQueueIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12L\n\tcondition\x18\x08 \x01(\x0b\x32\x39.oak9.tython.gcp.cloud.CloudTasksQueueIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb3\x01\n\x18\x43loudTasksQueueIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_cloud_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLOUDIDENTITYGROUP_LABELSENTRY._options = None
  _CLOUDIDENTITYGROUP_LABELSENTRY._serialized_options = b'8\001'
  _CLOUDRUNDOMAINMAPPINGXMETADATA_ANNOTATIONSENTRY._options = None
  _CLOUDRUNDOMAINMAPPINGXMETADATA_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _CLOUDRUNDOMAINMAPPINGXMETADATA_LABELSENTRY._options = None
  _CLOUDRUNDOMAINMAPPINGXMETADATA_LABELSENTRY._serialized_options = b'8\001'
  _CLOUDRUNDOMAINMAPPING_STATUSENTRY._options = None
  _CLOUDRUNDOMAINMAPPING_STATUSENTRY._serialized_options = b'8\001'
  _CLOUDRUNSERVICEXMETADATA_ANNOTATIONSENTRY._options = None
  _CLOUDRUNSERVICEXMETADATA_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _CLOUDRUNSERVICEXMETADATA_LABELSENTRY._options = None
  _CLOUDRUNSERVICEXMETADATA_LABELSENTRY._serialized_options = b'8\001'
  _CLOUDRUNSERVICEXTEMPLATEXMETADATA_ANNOTATIONSENTRY._options = None
  _CLOUDRUNSERVICEXTEMPLATEXMETADATA_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _CLOUDRUNSERVICEXTEMPLATEXMETADATA_LABELSENTRY._options = None
  _CLOUDRUNSERVICEXTEMPLATEXMETADATA_LABELSENTRY._serialized_options = b'8\001'
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXRESOURCES_LIMITSENTRY._options = None
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXRESOURCES_LIMITSENTRY._serialized_options = b'8\001'
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXRESOURCES_REQUESTSENTRY._options = None
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXRESOURCES_REQUESTSENTRY._serialized_options = b'8\001'
  _CLOUDRUNSERVICE_STATUSENTRY._options = None
  _CLOUDRUNSERVICE_STATUSENTRY._serialized_options = b'8\001'
  _CLOUDSCHEDULERJOBXAPPENGINEHTTPTARGET_HEADERSENTRY._options = None
  _CLOUDSCHEDULERJOBXAPPENGINEHTTPTARGET_HEADERSENTRY._serialized_options = b'8\001'
  _CLOUDSCHEDULERJOBXHTTPTARGET_HEADERSENTRY._options = None
  _CLOUDSCHEDULERJOBXHTTPTARGET_HEADERSENTRY._serialized_options = b'8\001'
  _CLOUDSCHEDULERJOBXPUBSUBTARGET_ATTRIBUTESENTRY._options = None
  _CLOUDSCHEDULERJOBXPUBSUBTARGET_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _CLOUDASSETFOLDERFEEDXCONDITION._serialized_start=67
  _CLOUDASSETFOLDERFEEDXCONDITION._serialized_end=173
  _CLOUDASSETFOLDERFEEDXFEEDOUTPUTCONFIGXPUBSUBDESTINATION._serialized_start=175
  _CLOUDASSETFOLDERFEEDXFEEDOUTPUTCONFIGXPUBSUBDESTINATION._serialized_end=247
  _CLOUDASSETFOLDERFEEDXFEEDOUTPUTCONFIG._serialized_start=250
  _CLOUDASSETFOLDERFEEDXFEEDOUTPUTCONFIG._serialized_end=397
  _CLOUDASSETFOLDERFEEDXTIMEOUTS._serialized_start=399
  _CLOUDASSETFOLDERFEEDXTIMEOUTS._serialized_end=478
  _CLOUDASSETFOLDERFEED._serialized_start=481
  _CLOUDASSETFOLDERFEED._serialized_end=963
  _CLOUDASSETORGANIZATIONFEEDXCONDITION._serialized_start=965
  _CLOUDASSETORGANIZATIONFEEDXCONDITION._serialized_end=1077
  _CLOUDASSETORGANIZATIONFEEDXFEEDOUTPUTCONFIGXPUBSUBDESTINATION._serialized_start=1079
  _CLOUDASSETORGANIZATIONFEEDXFEEDOUTPUTCONFIGXPUBSUBDESTINATION._serialized_end=1157
  _CLOUDASSETORGANIZATIONFEEDXFEEDOUTPUTCONFIG._serialized_start=1160
  _CLOUDASSETORGANIZATIONFEEDXFEEDOUTPUTCONFIG._serialized_end=1319
  _CLOUDASSETORGANIZATIONFEEDXTIMEOUTS._serialized_start=1321
  _CLOUDASSETORGANIZATIONFEEDXTIMEOUTS._serialized_end=1406
  _CLOUDASSETORGANIZATIONFEED._serialized_start=1409
  _CLOUDASSETORGANIZATIONFEED._serialized_end=1896
  _CLOUDASSETPROJECTFEEDXCONDITION._serialized_start=1898
  _CLOUDASSETPROJECTFEEDXCONDITION._serialized_end=2005
  _CLOUDASSETPROJECTFEEDXFEEDOUTPUTCONFIGXPUBSUBDESTINATION._serialized_start=2007
  _CLOUDASSETPROJECTFEEDXFEEDOUTPUTCONFIGXPUBSUBDESTINATION._serialized_end=2080
  _CLOUDASSETPROJECTFEEDXFEEDOUTPUTCONFIG._serialized_start=2083
  _CLOUDASSETPROJECTFEEDXFEEDOUTPUTCONFIG._serialized_end=2232
  _CLOUDASSETPROJECTFEEDXTIMEOUTS._serialized_start=2234
  _CLOUDASSETPROJECTFEEDXTIMEOUTS._serialized_end=2314
  _CLOUDASSETPROJECTFEED._serialized_start=2317
  _CLOUDASSETPROJECTFEED._serialized_end=2785
  _CLOUDIDENTITYGROUPXGROUPKEY._serialized_start=2787
  _CLOUDIDENTITYGROUPXGROUPKEY._serialized_end=2847
  _CLOUDIDENTITYGROUPXTIMEOUTS._serialized_start=2849
  _CLOUDIDENTITYGROUPXTIMEOUTS._serialized_end=2926
  _CLOUDIDENTITYGROUP._serialized_start=2929
  _CLOUDIDENTITYGROUP._serialized_end=3422
  _CLOUDIDENTITYGROUP_LABELSENTRY._serialized_start=3377
  _CLOUDIDENTITYGROUP_LABELSENTRY._serialized_end=3422
  _CLOUDIDENTITYGROUPMEMBERSHIPXPREFERREDMEMBERKEY._serialized_start=3424
  _CLOUDIDENTITYGROUPMEMBERSHIPXPREFERREDMEMBERKEY._serialized_end=3504
  _CLOUDIDENTITYGROUPMEMBERSHIPXROLES._serialized_start=3506
  _CLOUDIDENTITYGROUPMEMBERSHIPXROLES._serialized_end=3556
  _CLOUDIDENTITYGROUPMEMBERSHIPXTIMEOUTS._serialized_start=3558
  _CLOUDIDENTITYGROUPMEMBERSHIPXTIMEOUTS._serialized_end=3645
  _CLOUDIDENTITYGROUPMEMBERSHIP._serialized_start=3648
  _CLOUDIDENTITYGROUPMEMBERSHIP._serialized_end=4088
  _CLOUDRUNDOMAINMAPPINGXMETADATA._serialized_start=4091
  _CLOUDRUNDOMAINMAPPINGXMETADATA._serialized_end=4495
  _CLOUDRUNDOMAINMAPPINGXMETADATA_ANNOTATIONSENTRY._serialized_start=4398
  _CLOUDRUNDOMAINMAPPINGXMETADATA_ANNOTATIONSENTRY._serialized_end=4448
  _CLOUDRUNDOMAINMAPPINGXMETADATA_LABELSENTRY._serialized_start=3377
  _CLOUDRUNDOMAINMAPPINGXMETADATA_LABELSENTRY._serialized_end=3422
  _CLOUDRUNDOMAINMAPPINGXSPEC._serialized_start=4497
  _CLOUDRUNDOMAINMAPPINGXSPEC._serialized_end=4595
  _CLOUDRUNDOMAINMAPPINGXTIMEOUTS._serialized_start=4597
  _CLOUDRUNDOMAINMAPPINGXTIMEOUTS._serialized_end=4661
  _CLOUDRUNDOMAINMAPPING._serialized_start=4664
  _CLOUDRUNDOMAINMAPPING._serialized_end=5137
  _CLOUDRUNDOMAINMAPPING_STATUSENTRY._serialized_start=5092
  _CLOUDRUNDOMAINMAPPING_STATUSENTRY._serialized_end=5137
  _CLOUDRUNSERVICEXMETADATA._serialized_start=5140
  _CLOUDRUNSERVICEXMETADATA._serialized_end=5526
  _CLOUDRUNSERVICEXMETADATA_ANNOTATIONSENTRY._serialized_start=4398
  _CLOUDRUNSERVICEXMETADATA_ANNOTATIONSENTRY._serialized_end=4448
  _CLOUDRUNSERVICEXMETADATA_LABELSENTRY._serialized_start=3377
  _CLOUDRUNSERVICEXMETADATA_LABELSENTRY._serialized_end=3422
  _CLOUDRUNSERVICEXTEMPLATEXMETADATA._serialized_start=5529
  _CLOUDRUNSERVICEXTEMPLATEXMETADATA._serialized_end=5956
  _CLOUDRUNSERVICEXTEMPLATEXMETADATA_ANNOTATIONSENTRY._serialized_start=4398
  _CLOUDRUNSERVICEXTEMPLATEXMETADATA_ANNOTATIONSENTRY._serialized_end=4448
  _CLOUDRUNSERVICEXTEMPLATEXMETADATA_LABELSENTRY._serialized_start=3377
  _CLOUDRUNSERVICEXTEMPLATEXMETADATA_LABELSENTRY._serialized_end=3422
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXENVXVALUEFROMXSECRETKEYREF._serialized_start=5958
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXENVXVALUEFROMXSECRETKEYREF._serialized_end=6054
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXENVXVALUEFROM._serialized_start=6057
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXENVXVALUEFROM._serialized_end=6229
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXENV._serialized_start=6232
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXENV._serialized_end=6406
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXENVFROMXCONFIGMAPREFXLOCALOBJECTREFERENCE._serialized_start=6408
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXENVFROMXCONFIGMAPREFXLOCALOBJECTREFERENCE._serialized_end=6506
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXENVFROMXCONFIGMAPREF._serialized_start=6509
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXENVFROMXCONFIGMAPREF._serialized_end=6730
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXENVFROMXSECRETREFXLOCALOBJECTREFERENCE._serialized_start=6732
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXENVFROMXSECRETREFXLOCALOBJECTREFERENCE._serialized_end=6827
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXENVFROMXSECRETREF._serialized_start=6830
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXENVFROMXSECRETREF._serialized_end=7045
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXENVFROM._serialized_start=7048
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXENVFROM._serialized_end=7327
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXPORTS._serialized_start=7329
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXPORTS._serialized_end=7433
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXRESOURCES._serialized_start=7436
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXRESOURCES._serialized_end=7794
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXRESOURCES_LIMITSENTRY._serialized_start=7700
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXRESOURCES_LIMITSENTRY._serialized_end=7745
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXRESOURCES_REQUESTSENTRY._serialized_start=7747
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXRESOURCES_REQUESTSENTRY._serialized_end=7794
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXVOLUMEMOUNTS._serialized_start=7796
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERSXVOLUMEMOUNTS._serialized_end=7885
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERS._serialized_start=7888
  _CLOUDRUNSERVICEXTEMPLATEXSPECXCONTAINERS._serialized_end=8451
  _CLOUDRUNSERVICEXTEMPLATEXSPECXVOLUMESXSECRETXITEMS._serialized_start=8453
  _CLOUDRUNSERVICEXTEMPLATEXSPECXVOLUMESXSECRETXITEMS._serialized_end=8546
  _CLOUDRUNSERVICEXTEMPLATEXSPECXVOLUMESXSECRET._serialized_start=8549
  _CLOUDRUNSERVICEXTEMPLATEXSPECXVOLUMESXSECRET._serialized_end=8728
  _CLOUDRUNSERVICEXTEMPLATEXSPECXVOLUMES._serialized_start=8731
  _CLOUDRUNSERVICEXTEMPLATEXSPECXVOLUMES._serialized_end=8869
  _CLOUDRUNSERVICEXTEMPLATEXSPEC._serialized_start=8872
  _CLOUDRUNSERVICEXTEMPLATEXSPEC._serialized_end=9176
  _CLOUDRUNSERVICEXTEMPLATE._serialized_start=9179
  _CLOUDRUNSERVICEXTEMPLATE._serialized_end=9349
  _CLOUDRUNSERVICEXTIMEOUTS._serialized_start=9351
  _CLOUDRUNSERVICEXTIMEOUTS._serialized_end=9425
  _CLOUDRUNSERVICEXTRAFFIC._serialized_start=9427
  _CLOUDRUNSERVICEXTRAFFIC._serialized_end=9543
  _CLOUDRUNSERVICE._serialized_start=9546
  _CLOUDRUNSERVICE._serialized_end=10098
  _CLOUDRUNSERVICE_STATUSENTRY._serialized_start=5092
  _CLOUDRUNSERVICE_STATUSENTRY._serialized_end=5137
  _CLOUDRUNSERVICEIAMBINDINGXCONDITION._serialized_start=10100
  _CLOUDRUNSERVICEIAMBINDINGXCONDITION._serialized_end=10193
  _CLOUDRUNSERVICEIAMBINDING._serialized_start=10196
  _CLOUDRUNSERVICEIAMBINDING._serialized_end=10468
  _CLOUDRUNSERVICEIAMMEMBERXCONDITION._serialized_start=10470
  _CLOUDRUNSERVICEIAMMEMBERXCONDITION._serialized_end=10562
  _CLOUDRUNSERVICEIAMMEMBER._serialized_start=10565
  _CLOUDRUNSERVICEIAMMEMBER._serialized_end=10834
  _CLOUDRUNSERVICEIAMPOLICY._serialized_start=10837
  _CLOUDRUNSERVICEIAMPOLICY._serialized_end=11019
  _CLOUDSCHEDULERJOBXAPPENGINEHTTPTARGETXAPPENGINEROUTING._serialized_start=11021
  _CLOUDSCHEDULERJOBXAPPENGINEHTTPTARGETXAPPENGINEROUTING._serialized_end=11129
  _CLOUDSCHEDULERJOBXAPPENGINEHTTPTARGET._serialized_start=11132
  _CLOUDSCHEDULERJOBXAPPENGINEHTTPTARGET._serialized_end=11475
  _CLOUDSCHEDULERJOBXAPPENGINEHTTPTARGET_HEADERSENTRY._serialized_start=11429
  _CLOUDSCHEDULERJOBXAPPENGINEHTTPTARGET_HEADERSENTRY._serialized_end=11475
  _CLOUDSCHEDULERJOBXHTTPTARGETXOAUTHTOKEN._serialized_start=11477
  _CLOUDSCHEDULERJOBXHTTPTARGETXOAUTHTOKEN._serialized_end=11564
  _CLOUDSCHEDULERJOBXHTTPTARGETXOIDCTOKEN._serialized_start=11566
  _CLOUDSCHEDULERJOBXHTTPTARGETXOIDCTOKEN._serialized_end=11655
  _CLOUDSCHEDULERJOBXHTTPTARGET._serialized_start=11658
  _CLOUDSCHEDULERJOBXHTTPTARGET._serialized_end=12035
  _CLOUDSCHEDULERJOBXHTTPTARGET_HEADERSENTRY._serialized_start=11429
  _CLOUDSCHEDULERJOBXHTTPTARGET_HEADERSENTRY._serialized_end=11475
  _CLOUDSCHEDULERJOBXPUBSUBTARGET._serialized_start=12038
  _CLOUDSCHEDULERJOBXPUBSUBTARGET._serialized_end=12246
  _CLOUDSCHEDULERJOBXPUBSUBTARGET_ATTRIBUTESENTRY._serialized_start=12197
  _CLOUDSCHEDULERJOBXPUBSUBTARGET_ATTRIBUTESENTRY._serialized_end=12246
  _CLOUDSCHEDULERJOBXRETRYCONFIG._serialized_start=12249
  _CLOUDSCHEDULERJOBXRETRYCONFIG._serialized_end=12412
  _CLOUDSCHEDULERJOBXTIMEOUTS._serialized_start=12414
  _CLOUDSCHEDULERJOBXTIMEOUTS._serialized_end=12490
  _CLOUDSCHEDULERJOB._serialized_start=12493
  _CLOUDSCHEDULERJOB._serialized_end=13103
  _CLOUDTASKSQUEUEXAPPENGINEROUTINGOVERRIDE._serialized_start=13105
  _CLOUDTASKSQUEUEXAPPENGINEROUTINGOVERRIDE._serialized_end=13213
  _CLOUDTASKSQUEUEXRATELIMITS._serialized_start=13215
  _CLOUDTASKSQUEUEXRATELIMITS._serialized_end=13337
  _CLOUDTASKSQUEUEXRETRYCONFIG._serialized_start=13340
  _CLOUDTASKSQUEUEXRETRYCONFIG._serialized_end=13484
  _CLOUDTASKSQUEUEXSTACKDRIVERLOGGINGCONFIG._serialized_start=13486
  _CLOUDTASKSQUEUEXSTACKDRIVERLOGGINGCONFIG._serialized_end=13552
  _CLOUDTASKSQUEUEXTIMEOUTS._serialized_start=13554
  _CLOUDTASKSQUEUEXTIMEOUTS._serialized_end=13628
  _CLOUDTASKSQUEUE._serialized_start=13631
  _CLOUDTASKSQUEUE._serialized_end=14182
  _CLOUDTASKSQUEUEIAMBINDINGXCONDITION._serialized_start=14184
  _CLOUDTASKSQUEUEIAMBINDINGXCONDITION._serialized_end=14277
  _CLOUDTASKSQUEUEIAMBINDING._serialized_start=14280
  _CLOUDTASKSQUEUEIAMBINDING._serialized_end=14549
  _CLOUDTASKSQUEUEIAMMEMBERXCONDITION._serialized_start=14551
  _CLOUDTASKSQUEUEIAMMEMBERXCONDITION._serialized_end=14643
  _CLOUDTASKSQUEUEIAMMEMBER._serialized_start=14646
  _CLOUDTASKSQUEUEIAMMEMBER._serialized_end=14912
  _CLOUDTASKSQUEUEIAMPOLICY._serialized_start=14915
  _CLOUDTASKSQUEUEIAMPOLICY._serialized_end=15094
# @@protoc_insertion_point(module_scope)



import re
from typing import Iterator
from core.bp_metadata_utils.policy import Policy, PolicyProvider, SourceProvider

# implements_pattern = re.compile('^\s+Implements:\s*[\r\n](?P<desc>[\S\s]+)Returns', re.MULTILINE)
# desc_pattern = re.compile('^\s+Desc:\s*[\r\n](?P<desc>[\S\s]+)Implements', re.MULTILINE)

implements_pattern = re.compile('(Implements:\n\s+((((?P<implements>.+(?:\n.*?|\Z)+(\s*)))(Coverage:|Partial:|Desc:|References:|Implements|Returns:|\Z))))', re.MULTILINE)
desc_pattern = re.compile('Desc:\n\s+((((?P<desc>.+(?:\n.*?|\Z)+(\s*)))(Coverage:|Partial:|Desc:|References:|Implements|Returns:|\Z)))', re.MULTILINE)
no_desc_pattern = re.compile('(((((?P<nodesc>.+(?:\n.*?|\Z)+(\s*)))(Name:|Author:|\Z))))', re.MULTILINE)
coverage_pattern = re.compile('Coverage:\n\s+((?P<coverage>.+(?:\n.*?|\Z)+(\s*))(Coverage:|Partial:|Desc:|References:|Implements|Returns:|\Z))', re.MULTILINE)
references_pattern = re.compile('References:\n\s+(((?P<references>.+(?:\n.*?|\Z)+(\s*))(Coverage:|Partial:|Desc:|References:|Implements|Returns:|\Z)))', re.MULTILINE)
partial_pattern = re.compile('(Partial:\n\s+((((?P<partial>.+(?:\n.*?|\Z)+(\s*)))(Coverage:|Partial:|Desc:|References:|Implements|Returns:|\Z))))', re.MULTILINE)


class PolicyImplementationDocstring:
    """Representation of a docstring that links a use-case implementation to a vendor's policy/standard.

    References:
        AWS: https://aws.com

    Implements:
        AZURE_POLICY: https://github.com/Azure/azure-policy/blob/master/built-in-policies/policyDefinitions/Kubernetes/AKS_EncryptionAtHost_Deny.json
        AQUA_SECURITY_KUBE_BENCH: https://github.com/aquasecurity/kube-bench/cfg/cis-1.6/master.yaml
    Coverage:
        Partial:
            TODO (atcherniakhovski): Validate that this handles the case of multiple node-pools.
    """
    def __init__(self, docstring_raw: str) -> None:
        self._docstring_raw = docstring_raw


    @property
    def implementations(self) -> Iterator[Policy]:
        """
        Returns Policies that were implemented by the method to which the docstring is attached, an empty list otherwise.
        """
        matches = re.search(implements_pattern, self._docstring_raw)
        if not matches:
            return []

        for implementation in matches.group('implements').strip().split('\n'):
            # TODO: Refactor this to a regex and throw exceptions when the expected patter is not found.
            provider = implementation.split(':', 1)[0].strip()
            try:
                policy_provider = PolicyProvider[provider]
            except KeyError:
                policy_provider = PolicyProvider['OTHER']

            url = implementation.split(':', 1)[1].strip()

            # TODO: We only need the url to match this to a policy, but (for debugging purposes)
            # construct the name and description parameters. Consider, getting them from the docstring of the
            # implementing method.
            yield Policy(name='', description='', provider=policy_provider, url=url)

    @property
    def desc(self) -> str:
        """
        Returns blueprint name
        """
        empty_msg = "No description provided in docstring"
        desc = self._get_str_field(desc_pattern, 'desc', empty_msg)
        if desc == empty_msg:
            desc = self._get_str_field(no_desc_pattern, 'nodesc', empty_msg)

        return desc

    @property
    def coverage(self) -> str:
        """
        Returns blueprint name
        """
        empty_msg = "No coverage information provided in docstring"
        coverage = self._get_str_field(coverage_pattern, 'coverage', empty_msg)
        return coverage

    @property
    def references(self) -> Iterator[Policy]:
        """
        Returns blueprint name
        """
        matches = re.search(references_pattern, self._docstring_raw)
        if not matches:
            return []

        for reference in matches.group('references').strip().split('\n'):
            # TODO: Refactor this to a regex and throw exceptions when the expected patter is not found.
            source = reference.split(':', 1)[0].strip()
            try:
                policy_provider = SourceProvider[source]
            except KeyError:
                policy_provider = SourceProvider.OTHER

            url = reference.split(':', 1)[1].strip()

            # TODO: We only need the url to match this to a policy, but (for debugging purposes)
            # construct the name and description parameters. Consider, getting them from the docstring of the
            # implementing method.
            yield Policy(name='', description='', provider=policy_provider, url=url)

    def _get_str_field(self, pattern: re, group: str, empty_msg: str) -> str:
        """
        Returns string value for simple fields defined in the blueprint or function docstring
        """
        matches = re.search(pattern, self._docstring_raw)
        if not matches:
            return empty_msg

        # Assume first item is what we want
        result = matches.group(group).strip().split('\n')[0]

        return result



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: shared/shared.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13shared/shared.proto\x12\x12oak9.tython.shared\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\"\xc6\x05\n\tBlueprint\x12\x14\n\x0c\x62lueprint_id\x18\x01 \x01(\t\x12\x1b\n\x13parent_blueprint_id\x18\x02 \x01(\t\x12\x16\n\x0e\x62lueprint_name\x18\x03 \x01(\t\x12\x13\n\x06status\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x06 \x01(\t\x12\x10\n\x08revision\x18\x07 \x01(\t\x12\x0f\n\x07version\x18\x08 \x01(\t\x12\x0e\n\x06\x61uthor\x18\t \x01(\t\x12\x1d\n\x15\x63ompliance_objectives\x18\n \x03(\t\x12\x33\n\x0flast_updated_on\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x0e\x63omponent_info\x18\x0c \x01(\x0b\x32!.oak9.tython.shared.ComponentInfo\x12M\n\x13\x62lueprint_reference\x18\r \x01(\x0b\x32+.oak9.tython.shared.ReferencedDocumentModelH\x01\x88\x01\x01\x12\x35\n\x0crequirements\x18\x0e \x03(\x0b\x32\x1f.oak9.tython.shared.Requirement\x12\x12\n\nis_deleted\x18\x0f \x01(\x08\x12!\n\x14reference_project_id\x18\x10 \x01(\tH\x02\x88\x01\x01\x12,\n\x07\x63ontext\x18\x11 \x01(\x0b\x32\x1b.oak9.tython.shared.Context\x12\x31\n\nblueprints\x18\x12 \x03(\x0b\x32\x1d.oak9.tython.shared.Blueprint\x12\x1a\n\x12\x62lueprint_location\x18\x13 \x01(\tB\t\n\x07_statusB\x16\n\x14_blueprint_referenceB\x17\n\x15_reference_project_id\"\xcf\x01\n\rComponentInfo\x12\x14\n\x0c\x63omponent_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x19\n\x11\x63omponent_type_id\x18\x04 \x01(\t\x12\x12\n\nx_position\x18\x05 \x01(\x11\x12\x12\n\ny_position\x18\x06 \x01(\x11\x12\x36\n\x0b\x63onnections\x18\x07 \x03(\x0b\x32!.oak9.tython.shared.ComponentInfo\x12\x11\n\tcollapsed\x18\x08 \x01(\x08\"\x98\x01\n\x17ReferencedDocumentModel\x12\x13\n\x0b\x65ntity_type\x18\x01 \x01(\t\x12\x16\n\x0ereference_type\x18\x02 \x01(\t\x12\x15\n\rreference_key\x18\x03 \x01(\t\x12\x1c\n\x14\x64ocument_primary_key\x18\x04 \x01(\t\x12\x1b\n\x13\x64ocument_entity_key\x18\x05 \x01(\t\"\xf7\x04\n\x0bRequirement\x12\x0f\n\x02id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12,\n\x07\x63ontext\x18\x02 \x01(\x0b\x32\x1b.oak9.tython.shared.Context\x12\x18\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07version\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04type\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x15\n\x08\x63\x61tegory\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\x19\n\x0csub_category\x18\x07 \x01(\tH\x05\x88\x01\x01\x12\x16\n\tcomponent\x18\x08 \x01(\tH\x06\x88\x01\x01\x12\x11\n\x04tags\x18\t \x01(\tH\x07\x88\x01\x01\x12\x15\n\x08guidance\x18\n \x01(\tH\x08\x88\x01\x01\x12\x1d\n\x10hi_trust_mapping\x18\x0b \x01(\tH\t\x88\x01\x01\x12\x1f\n\x12hi_trust94_mapping\x18\x0c \x01(\tH\n\x88\x01\x01\x12\x19\n\x0cnist_mapping\x18\r \x01(\tH\x0b\x88\x01\x01\x12N\n\x13industry_frameworks\x18\x0e \x03(\x0b\x32\x31.oak9.tython.shared.IndustryFrameworkMappingModel\x12\x12\n\x05hl_rs\x18\x0f \x01(\tH\x0c\x88\x01\x01\x42\x05\n\x03_idB\x0e\n\x0c_descriptionB\n\n\x08_versionB\x07\n\x05_typeB\x0b\n\t_categoryB\x0f\n\r_sub_categoryB\x0c\n\n_componentB\x07\n\x05_tagsB\x0b\n\t_guidanceB\x13\n\x11_hi_trust_mappingB\x15\n\x13_hi_trust94_mappingB\x0f\n\r_nist_mappingB\x08\n\x06_hl_rs\"[\n\x1dIndustryFrameworkMappingModel\x12\x1d\n\x15industry_framework_id\x18\x01 \x01(\t\x12\x1b\n\x13mapped_requirements\x18\x02 \x03(\t\"\xaf\x02\n\x07\x43ontext\x12\x42\n\raccessibility\x18\x01 \x01(\x0b\x32+.oak9.tython.shared.AccessibilityAttributes\x12\x44\n\x0esusceptibility\x18\x02 \x01(\x0b\x32,.oak9.tython.shared.SusceptibilityAttributes\x12G\n\x10\x61pp_architecture\x18\x03 \x01(\x0b\x32-.oak9.tython.shared.AppArchitectureAttributes\x12Q\n\x15security_architecture\x18\x04 \x01(\x0b\x32\x32.oak9.tython.shared.SecurityArchitectureAttributes\"\x8f\x02\n\x17\x41\x63\x63\x65ssibilityAttributes\x12/\n\tend_users\x18\x01 \x01(\x0b\x32\x1c.oak9.tython.shared.EndUsers\x12:\n\x0flevel_of_access\x18\x02 \x01(\x0b\x32!.oak9.tython.shared.LevelOfAccess\x12\x33\n\x0b\x61\x63\x63\x65ss_type\x18\x03 \x01(\x0b\x32\x1e.oak9.tython.shared.AccessType\x12R\n\x1b\x61pplicable_component_slices\x18\x04 \x01(\x0b\x32-.oak9.tython.shared.ApplicableComponentSlices\"K\n\x08\x45ndUsers\x12\x11\n\tworkforce\x18\x01 \x01(\t\x12\x11\n\tconsumers\x18\x02 \x01(\t\x12\x19\n\x11\x62usiness_partners\x18\x03 \x01(\t\"\x8a\x01\n\rLevelOfAccess\x12\x10\n\x08physical\x18\x01 \x01(\t\x12\x0c\n\x04open\x18\x02 \x01(\t\x12\x1e\n\x16limited_sensitive_data\x18\x03 \x01(\t\x12\x1c\n\x14\x62road_sensitive_data\x18\x04 \x01(\t\x12\x1b\n\x13security_privileged\x18\x05 \x01(\t\"\x87\x01\n\nAccessType\x12\x17\n\x0f\x65xternal_access\x18\x01 \x01(\t\x12\x17\n\x0finternal_access\x18\x02 \x01(\t\x12\x15\n\rremote_access\x18\x03 \x01(\t\x12\x17\n\x0fwireless_access\x18\x04 \x01(\t\x12\x17\n\x0foutbound_access\x18\x05 \x01(\t\"i\n\x19\x41pplicableComponentSlices\x12\x16\n\x0e\x63omponent_core\x18\x01 \x01(\t\x12\x16\n\x0euser_interface\x18\x02 \x01(\t\x12\x1c\n\x14management_interface\x18\x03 \x01(\t\"M\n\x18SusceptibilityAttributes\x12\x18\n\x10\x64\x61ta_sensitivity\x18\x01 \x01(\t\x12\x17\n\x0f\x62usiness_impact\x18\x02 \x01(\t\"5\n\x19\x41ppArchitectureAttributes\x12\x18\n\x10\x64\x65ployment_model\x18\x01 \x01(\t\"8\n\x1eSecurityArchitectureAttributes\x12\x16\n\x0esecurity_level\x18\x01 \x01(\t\"\x9e\x03\n\tDesignGap\x12\x15\n\rcapability_id\x18\x01 \x01(\t\x12\x17\n\x0f\x63\x61pability_name\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\x12\x15\n\rresource_name\x18\x04 \x01(\t\x12\x13\n\x0bresource_id\x18\x05 \x01(\t\x12\x15\n\rresource_type\x18\x06 \x01(\t\x12\x19\n\x0cresource_gap\x18\x07 \x01(\tH\x00\x88\x01\x01\x12\x1c\n\x0fresource_impact\x18\x08 \x01(\tH\x01\x88\x01\x01\x12\x31\n\nviolations\x18\t \x03(\x0b\x32\x1d.oak9.tython.shared.Violation\x12\x1a\n\roak9_guidance\x18\n \x01(\tH\x02\x88\x01\x01\x12O\n\x1amapped_industry_frameworks\x18\x0b \x03(\x0b\x32+.oak9.tython.shared.MappedIndustryFrameworkB\x0f\n\r_resource_gapB\x12\n\x10_resource_impactB\x10\n\x0e_oak9_guidance\"\xc9\x04\n\tViolation\x12\x15\n\x08severity\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x17\n\nconfig_gap\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1a\n\rcapability_id\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x18\n\x0bresource_id\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x1a\n\rresource_type\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x16\n\tconfig_id\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x19\n\x0c\x63onfig_value\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x1a\n\roak9_guidance\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x1c\n\x0fpreffered_value\x18\t \x01(\tH\x08\x88\x01\x01\x12\x1c\n\x0f\x63\x61pability_name\x18\n \x01(\tH\t\x88\x01\x01\x12\x17\n\nconfig_fix\x18\x0b \x01(\tH\n\x88\x01\x01\x12\x1a\n\rconfig_impact\x18\x0c \x01(\tH\x0b\x88\x01\x01\x12\x1c\n\x0f\x65xisting_config\x18\r \x01(\x08H\x0c\x88\x01\x01\x42\x0b\n\t_severityB\r\n\x0b_config_gapB\x10\n\x0e_capability_idB\x0e\n\x0c_resource_idB\x10\n\x0e_resource_typeB\x0c\n\n_config_idB\x0f\n\r_config_valueB\x10\n\x0e_oak9_guidanceB\x12\n\x10_preffered_valueB\x12\n\x10_capability_nameB\r\n\x0b_config_fixB\x10\n\x0e_config_impactB\x12\n\x10_existing_config\"_\n\x17MappedIndustryFramework\x12\x19\n\x11industry_standard\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\";\n\x05Graph\x12\x32\n\nroot_nodes\x18\x01 \x03(\x0b\x32\x1e.oak9.tython.shared.Connection\"\x8d\x01\n\nConnection\x12(\n\x04node\x18\x01 \x01(\x0b\x32\x1a.oak9.tython.shared.Vertex\x12\"\n\x04\x65\x64ge\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x31\n\tneighbors\x18\x03 \x03(\x0b\x32\x1e.oak9.tython.shared.Connection\"\x90\x01\n\x06Vertex\x12\x11\n\tunique_id\x18\x01 \x01(\t\x12\x33\n\x0bvertex_type\x18\x02 \x01(\x0e\x32\x1e.oak9.tython.shared.VertexType\x12\x0e\n\x06labels\x18\x03 \x03(\t\x12.\n\x08resource\x18\x04 \x01(\x0b\x32\x1c.oak9.tython.shared.Resource\"\xdc\x02\n\x0cResourceInfo\x12\x0f\n\x02id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x10\n\x03\x63sp\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1a\n\rresource_type\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x38\n\x04tags\x18\x05 \x03(\x0b\x32*.oak9.tython.shared.ResourceInfo.TagsEntry\x12\x19\n\x0c\x62lueprint_id\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\x31\n\x07\x63ontext\x18\x07 \x01(\x0b\x32\x1b.oak9.tython.shared.ContextH\x05\x88\x01\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x05\n\x03_idB\x07\n\x05_nameB\x06\n\x04_cspB\x10\n\x0e_resource_typeB\x0f\n\r_blueprint_idB\n\n\x08_context\".\n\x08Resource\x12\"\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\"<\n\x0fRunnerException\x12\x12\n\nerror_code\x18\x01 \x01(\t\x12\x15\n\rerror_message\x18\x02 \x01(\t\"\xda\x01\n\x0bRunnerInput\x12(\n\x05graph\x18\x01 \x01(\x0b\x32\x19.oak9.tython.shared.Graph\x12\x30\n\tblueprint\x18\x02 \x01(\x0b\x32\x1d.oak9.tython.shared.Blueprint\x12\x34\n\x0fproject_context\x18\x03 \x01(\x0b\x32\x1b.oak9.tython.shared.Context\x12\x39\n\tmeta_info\x18\x04 \x01(\x0b\x32&.oak9.tython.shared.ValidationMetaInfo\"\xb0\x01\n\x12ValidationMetaInfo\x12\x0e\n\x06\x63\x61ller\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\t\x12\x15\n\rresource_type\x18\x03 \x01(\t\x12\x14\n\x0c\x62lueprint_id\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12\x13\n\x0bresource_id\x18\x06 \x01(\t\x12\x1d\n\x15\x63ompliance_objectives\x18\x07 \x03(\t\"\xbf\x01\n\x0fValidationReply\x12\x32\n\x0b\x64\x65sign_gaps\x18\x01 \x03(\x0b\x32\x1d.oak9.tython.shared.DesignGap\x12?\n\x0crequirements\x18\x02 \x03(\x0b\x32).oak9.tython.shared.ValidationRequirement\x12\x37\n\nexceptions\x18\x03 \x03(\x0b\x32#.oak9.tython.shared.RunnerException\"j\n\x15ValidationRequirement\x12=\n\x10requirement_type\x18\x01 \x01(\x0e\x32#.oak9.tython.shared.RequirementType\x12\x12\n\nparameters\x18\x02 \x03(\t*\x99\x02\n\nVertexType\x12\x0b\n\x07GENERIC\x10\x00\x12\x0f\n\x0bREQUIREMENT\x10\x01\x12\x18\n\x14\x44\x45TAILED_REQUIREMENT\x10\x02\x12\x16\n\x12IL_MAPPING_KEYWORD\x10\x03\x12\x19\n\x15\x41WS_INSTANCE_RESOURCE\x10\x04\x12\x17\n\x13\x41WS_SUBNET_RESOURCE\x10\x05\x12\x14\n\x10\x41WS_VPC_RESOURCE\x10\x06\x12\x1f\n\x1b\x41WS_SECURITY_GROUP_RESOURCE\x10\x07\x12\x1b\n\x17\x41WS_ELASTIC_LB_RESOURCE\x10\x08\x12\x17\n\x13\x43LOUDFRONT_RESOURCE\x10\t\x12\x1a\n\x16LOAD_BALANCER_RESOURCE\x10\n*l\n\x0fRequirementType\x12\x11\n\rALL_NEIGHBORS\x10\x00\x12\x15\n\x11NEIGHBORS_OF_TYPE\x10\x01\x12\x1e\n\x1aNEIGHBOR_WITH_RELATIONSHIP\x10\x02\x12\x0f\n\x0bWHOLE_GRAPH\x10\x03\x32[\n\x06Runner\x12Q\n\x03Run\x12\x1f.oak9.tython.shared.RunnerInput\x1a#.oak9.tython.shared.ValidationReply\"\x00(\x01\x30\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'shared.shared_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESOURCEINFO_TAGSENTRY._options = None
  _RESOURCEINFO_TAGSENTRY._serialized_options = b'8\001'
  _VERTEXTYPE._serialized_start=5761
  _VERTEXTYPE._serialized_end=6042
  _REQUIREMENTTYPE._serialized_start=6044
  _REQUIREMENTTYPE._serialized_end=6152
  _BLUEPRINT._serialized_start=104
  _BLUEPRINT._serialized_end=814
  _COMPONENTINFO._serialized_start=817
  _COMPONENTINFO._serialized_end=1024
  _REFERENCEDDOCUMENTMODEL._serialized_start=1027
  _REFERENCEDDOCUMENTMODEL._serialized_end=1179
  _REQUIREMENT._serialized_start=1182
  _REQUIREMENT._serialized_end=1813
  _INDUSTRYFRAMEWORKMAPPINGMODEL._serialized_start=1815
  _INDUSTRYFRAMEWORKMAPPINGMODEL._serialized_end=1906
  _CONTEXT._serialized_start=1909
  _CONTEXT._serialized_end=2212
  _ACCESSIBILITYATTRIBUTES._serialized_start=2215
  _ACCESSIBILITYATTRIBUTES._serialized_end=2486
  _ENDUSERS._serialized_start=2488
  _ENDUSERS._serialized_end=2563
  _LEVELOFACCESS._serialized_start=2566
  _LEVELOFACCESS._serialized_end=2704
  _ACCESSTYPE._serialized_start=2707
  _ACCESSTYPE._serialized_end=2842
  _APPLICABLECOMPONENTSLICES._serialized_start=2844
  _APPLICABLECOMPONENTSLICES._serialized_end=2949
  _SUSCEPTIBILITYATTRIBUTES._serialized_start=2951
  _SUSCEPTIBILITYATTRIBUTES._serialized_end=3028
  _APPARCHITECTUREATTRIBUTES._serialized_start=3030
  _APPARCHITECTUREATTRIBUTES._serialized_end=3083
  _SECURITYARCHITECTUREATTRIBUTES._serialized_start=3085
  _SECURITYARCHITECTUREATTRIBUTES._serialized_end=3141
  _DESIGNGAP._serialized_start=3144
  _DESIGNGAP._serialized_end=3558
  _VIOLATION._serialized_start=3561
  _VIOLATION._serialized_end=4146
  _MAPPEDINDUSTRYFRAMEWORK._serialized_start=4148
  _MAPPEDINDUSTRYFRAMEWORK._serialized_end=4243
  _GRAPH._serialized_start=4245
  _GRAPH._serialized_end=4304
  _CONNECTION._serialized_start=4307
  _CONNECTION._serialized_end=4448
  _VERTEX._serialized_start=4451
  _VERTEX._serialized_end=4595
  _RESOURCEINFO._serialized_start=4598
  _RESOURCEINFO._serialized_end=4946
  _RESOURCEINFO_TAGSENTRY._serialized_start=4832
  _RESOURCEINFO_TAGSENTRY._serialized_end=4875
  _RESOURCE._serialized_start=4948
  _RESOURCE._serialized_end=4994
  _RUNNEREXCEPTION._serialized_start=4996
  _RUNNEREXCEPTION._serialized_end=5056
  _RUNNERINPUT._serialized_start=5059
  _RUNNERINPUT._serialized_end=5277
  _VALIDATIONMETAINFO._serialized_start=5280
  _VALIDATIONMETAINFO._serialized_end=5456
  _VALIDATIONREPLY._serialized_start=5459
  _VALIDATIONREPLY._serialized_end=5650
  _VALIDATIONREQUIREMENT._serialized_start=5652
  _VALIDATIONREQUIREMENT._serialized_end=5758
  _RUNNER._serialized_start=6154
  _RUNNER._serialized_end=6245
# @@protoc_insertion_point(module_scope)
